##  Step 5: Connect Elements
Connectors are lines or arrows that visually connect elements in your diagram. You can use them to show relations between shapes and fact sheets.
### Add Basic Connector Shapes
To manually draw a connector between two shapes:
  1. From the shape library, select a connector shape from categories like General or Arrows.
  2. Drag the connector onto the canvas between the shapes you want to connect.
  3. Adjust the connector's endpoints by dragging them to connect to specific shapes.
  4. Optional: Use the format panel to adjust arrowheads, color, and line style.


![A gif showing several types of elements being connected with different types of connectors.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio63b2ff24ea034992a153a965dd326014_LowRes.gif)
Connecting Elements in the Editor
### Add Connections Between Fact Sheets
When working with fact sheets, you can visualize relations based on the data in your inventory. For detailed information about visualizing dependencies, see:
  * Free Draw
    * [Types of Connections Between Fact Sheets](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__types_of_connections_between_fact_sheets)
    * [Expanding Relations](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__section_zxh_1qs_bhc)
    * [Expanding Interfaces](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a369c7a4410148ff4e12bcf658e03__expanding_interfaces)
  * Data Flow
    * [Expanding Interfaces](https://help.sap.com/docs/leanix/ea/data-flow?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759ae097a441014acff8ab536c79254__expanding_interfaces)
